gsl

package module
v1.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 10, 2020 License: MIT Imports: 0 Imported by: 8

README

gsl: Structure Logging Interface

godoc sec go-report license

A small opinionated log interface for Go for structured logging. Only supports 2 types of logs:

  • Info: For informational logging.
  • Error: For error logging.
API

The gsl.Log interface exposes the following methods:

  • With(fields map[string]interface{}) GGLog: Provide a new logger that will include the fields in subsequent logs.
  • Info(message string): Log the provided message at the info level.
  • Infof(format string, v ...interface{}): Format and log the provided message at the info level.
  • Infow(fields map[string]interface{}, message string): A shortened version of With(fields).Info(message).
  • Infofw(fields map[string]interface{}, format string, v ...interface{}): A shortened version of With(fields).Infof(message, v...).
  • Error(message string): Log the provided message at the error level.
  • Errorf(format string, v ...interface{}): Format and log the provided message at the error level.
  • Errorw(fields map[string]interface{}, message string): A shortened version of With(fields).Error(message).
  • Errorfw(fields map[string]interface{}, format string, v ...interface{}): A shortened version of With(fields).Errorf(message, v...).
  • V(verbosity int) bool: Determine if the provided verbosity is supported.

Implementations

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Log

type Log interface {
	With(fields map[string]interface{}) Log
	Info(message string)
	Infof(format string, v ...interface{})
	Infow(fields map[string]interface{}, message string)
	Infofw(fields map[string]interface{}, format string, v ...interface{})
	Error(message string)
	Errorf(format string, v ...interface{})
	Errorw(fields map[string]interface{}, message string)
	Errorfw(fields map[string]interface{}, format string, v ...interface{})
	V(verbosity int) bool
}

Log is an interface for logging.

Jump to